@@ -67,6 +67,7 @@ class Q_DECL_HIDDEN KIdentityManagement::IdentityManager::Private
 {
 public:
     Private(KIdentityManagement::IdentityManager *);
+    ~Private();
     void writeConfig() const;
     void readConfig(KConfig *config);
     void createDefaultIdentity();
@@ -697,5 +698,10 @@ void KIdentityManagement::IdentityManager::slotRollback()
     rollback();
 }
 
+IdentityManager::Private::~Private()
+{
+    delete mConfig;
+}
+
 }
 #include "moc_identitymanager.cpp"
